#!/usr/bin/env python
##################################################
# Gnuradio Python Flow Graph
# Title: USRP Quad Source
# Author: Karthik Vijayraghavan
# Description: USRP Quad Source
# Generated: Mon Nov 23 11:08:40 2009
##################################################

from gnuradio import gr
from gnuradio import usrp,gru

class usrp_quad_source_f(gr.hier_block2):

	def __init__(self, decimation=16, fusb_block_size=512*8, fusb_nblocks=512*8, gain_aa=0, gain_ba=0, gain_ab=0, gain_bb=0):
		gr.hier_block2.__init__(
			self, "USRP Quad Source",
			gr.io_signature(0, 0, 0*0),
			gr.io_signature(4, 4, gr.sizeof_float*1),
		)

		##################################################
		# Parameters
		##################################################
		self.decimation = decimation
		self.fusb_block_size = fusb_block_size
		self.fusb_nblocks = fusb_nblocks
		self.gain_aa = gain_aa
		self.gain_ba = gain_ba
		self.gain_ab = gain_ab
		self.gain_bb = gain_bb

		##################################################
		# Blocks
		##################################################
		self.gr_complex_to_float_0 = gr.complex_to_float(1)
		self.gr_complex_to_float_1 = gr.complex_to_float(1)
		self.gr_deinterleave_0 = gr.deinterleave(gr.sizeof_gr_complex*1)
		self.usrp_quad_source_helper_0 = usrp.source_c(decim_rate=decimation,nchan=2,fusb_block_size=fusb_block_size,fusb_nblocks=fusb_nblocks)
		self.usrp_quad_source_helper_0.set_mux(gru.hexint(0x32103210))
		self.subdev_aa = self.usrp_quad_source_helper_0.selected_subdev((0,0))
		self.subdev_ab = self.usrp_quad_source_helper_0.selected_subdev((0,1))
		self.subdev_ba = self.usrp_quad_source_helper_0.selected_subdev((1,0))
		self.subdev_bb = self.usrp_quad_source_helper_0.selected_subdev((1,1))
		self.subdev_aa.set_gain(gain_aa)
		self.subdev_ab.set_gain(gain_ab)
		self.subdev_ba.set_gain(gain_ba)
		self.subdev_bb.set_gain(gain_bb)
		self.usrp_quad_source_helper_0.set_rx_freq(0,0.0)
			

		##################################################
		# Connections
		##################################################
		self.connect((self.usrp_quad_source_helper_0, 0), (self.gr_deinterleave_0, 0))
		self.connect((self.gr_deinterleave_0, 0), (self.gr_complex_to_float_0, 0))
		self.connect((self.gr_deinterleave_0, 1), (self.gr_complex_to_float_1, 0))
		self.connect((self.gr_complex_to_float_0, 0), (self, 0))
		self.connect((self.gr_complex_to_float_0, 1), (self, 1))
		self.connect((self.gr_complex_to_float_1, 0), (self, 2))
		self.connect((self.gr_complex_to_float_1, 1), (self, 3))

	def set_decimation(self, decimation):
		self.decimation = decimation

	def set_fusb_block_size(self, fusb_block_size):
		self.fusb_block_size = fusb_block_size

	def set_fusb_nblocks(self, fusb_nblocks):
		self.fusb_nblocks = fusb_nblocks

	def set_gain_aa(self, gain_aa):
		self.gain_aa = gain_aa

	def set_gain_ba(self, gain_ba):
		self.gain_ba = gain_ba

	def set_gain_ab(self, gain_ab):
		self.gain_ab = gain_ab

	def set_gain_bb(self, gain_bb):
		self.gain_bb = gain_bb


